@@ -23,13 +23,20 @@
 
 #ifndef LIBKGAPI2_DEPRECATED
 #  define LIBKGAPI2_DEPRECATED __attribute__ ((__deprecated__))
-#  define LIBKGAPI2_DEPRECATED_EXPORT LIBKGAPI2_EXPORT __attribute__ ((__deprecated__))
-#  define LIBKGAPI2_DEPRECATED_NO_EXPORT LIBKGAPI2_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define LIBKGAPI2_NO_DEPRECATED
+#ifndef LIBKGAPI2_DEPRECATED_EXPORT
+#  define LIBKGAPI2_DEPRECATED_EXPORT LIBKGAPI2_EXPORT LIBKGAPI2_DEPRECATED
 #endif
 
+#ifndef LIBKGAPI2_DEPRECATED_NO_EXPORT
+#  define LIBKGAPI2_DEPRECATED_NO_EXPORT LIBKGAPI2_NO_EXPORT LIBKGAPI2_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef LIBKGAPI2_NO_DEPRECATED
+#    define LIBKGAPI2_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* LIBKGAPI2_EXPORT_H */
